==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/plugins/GUITestBase/src/runnables/ugene/corelibs/U2Gui/RangeSelectionDialogFiller.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_GT_RUNNABLES_RANGE_SELECTION_DIALOG_FILLER_H_
#define _U2_GT_RUNNABLES_RANGE_SELECTION_DIALOG_FILLER_H_

#include "utils/GTUtilsDialog.h"

namespace U2 {
using namespace HI;

class SelectSequenceRegionDialogFiller : public Filler {
public:
    enum RangeType { Single,
                     Multiple };
    SelectSequenceRegionDialogFiller(HI::GUITestOpStatus &_os, int *_len);
    SelectSequenceRegionDialogFiller(HI::GUITestOpStatus &_os, CustomScenario *scenario = nullptr);
    SelectSequenceRegionDialogFiller(HI::GUITestOpStatus &_os, int _minVal, int _maxVal);
    SelectSequenceRegionDialogFiller(HI::GUITestOpStatus &_os, const QString &range);
    SelectSequenceRegionDialogFiller(HI::GUITestOpStatus &_os, int _length, bool selectFromBegin = true);

    void commonScenario();
    void setCircular(bool v);

private:
    RangeType rangeType;
    bool selectAll, fromBegin;
    int minVal, maxVal, length, *len;
    QString multipleRange;
    bool circular;
};

}  // namespace U2

#endif

==> ugene_49.1+dfsg.orig.tar.xz: ugene-49.1/src/plugins/GUITestBase/src/runnables/ugene/corelibs/U2Gui/RangeSelectionDialogFiller.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#pragma once

#include "utils/GTUtilsDialog.h"

namespace U2 {
using namespace HI;

class SelectSequenceRegionDialogFiller : public Filler {
public:
    enum RangeType { Single,
                     Multiple };
    SelectSequenceRegionDialogFiller(int* _len);
    SelectSequenceRegionDialogFiller(CustomScenario* scenario = nullptr);
    SelectSequenceRegionDialogFiller(int _minVal, int _maxVal);
    SelectSequenceRegionDialogFiller(const QString& range);
    SelectSequenceRegionDialogFiller(int _length, bool selectFromBegin = true);

    void commonScenario();
    void setCircular(bool v);

private:
    RangeType rangeType;
    bool selectAll, fromBegin;
    int minVal, maxVal, length, *len;
    QString multipleRange;
    bool circular;
};

}  // namespace U2
